Versions
========

0.0.1
========

_Release date: 17.10.2020_

**Features**

- Create test status report table based on XML file
- Use `--confluence-upload/--cu` pytest parameter to enable plugin
- Use `--confluence-settings/--sc` and `--pytest-xml-path/--px` optional pytest parameters to customize behaviour

**Changes**

- Build test status table from XML file
- Note about settings file completion
- Simplify report page builder interface
- Create report page instance
- Implement report from XML logic
- Implement initial XML composition
- Use typer CLI tool
- Add empty page unit tests
- Define used tools
- Create Confluence page interface
- Integrate confluence uploader within pytest
- Use `--confluence-upload` pytest parameter
